<?php
class Lesson extends Application
{
	public $db;
	private $userid;

	public function __construct($userid, $id = '')	{
		//fetch db from Application for reference
		$this->db = parent::getDatabase();
		$this->userid = $userid;
		if($id != '') {
			$sql = "SELECT * FROM `lessons` WHERE `id` = :id";
			$query = $this->db->prepare($sql);
			$query->execute(array(':id' => $id));
			$order = $query->fetch();
			if($order) {
				foreach($order as $n=>$v) {
					$this->$n = $v;
				}
			}
		}
	}

	public function add($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `lessons`(";
			$fields = array();

			/* handle reel link updates */
			if(!empty($data['video_link'])) {
				$data['video_link'] = $this->convertFacebookReelLink($data['video_link']);
			}

			//list of fields in the table
			$clearing_fields = array(
				'active',
				'created_user_id',
				'updated_user_id',
				'title',
				'content',
				'content_quill',
				'sort_order',
				'video_link'
			);

			foreach($clearing_fields as $field) {
				$fields[$field] = $data[$field];
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}

			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";
				}
				$i++;
			}

			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$id = $this->db->lastInsertId();

			if(!isset($data['tags'])) {
				$data['tags'] = '';
			} else {
				//add current tags
				foreach($data['tags'] as $tag) {
					$tag_update = "INSERT INTO  `lesson_to_tags`(`lesson_id`, `tag_id`) VALUES (:id,:tag_id)";
					$query = $this->db->prepare($tag_update);
					$query->execute(array('id'=>$id, 'tag_id'=>$tag));
				}
			}

			unset($data['tags']);

		}
		return;
	}

	public function update($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `lessons` SET";
			$fields = array();

			/* handle reel link updates */
			if(!empty($data['video_link'])) {
				$data['video_link'] = $this->convertFacebookReelLink($data['video_link']);
			}
			//list of fields in the table
			$table_fields = array(
				'active',
				'created_user_id',
				'updated_user_id',
				'title',
				'sort_order',
				'content',
				'content_quill',
				'video_link'
			);

			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					$fields[$field] = $data[$field];
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}

			if(!isset($data['tags'])) {
				$data['tags'] = '';
			} else {
				//remove all existing tags
				$tag_delete = "DELETE FROM `lesson_to_tags` WHERE `lesson_id`=:id";
				$query = $this->db->prepare($tag_delete);
				$query->execute(array('id'=>$data['id']));

				//add current tags
				foreach($data['tags'] as $tag) {
					$tag_update = "INSERT INTO  `lesson_to_tags`(`lesson_id`, `tag_id`) VALUES (:id,:tag_id)";
					$query = $this->db->prepare($tag_update);
					$query->execute(array('id'=>$data['id'], 'tag_id'=>$tag));
				}
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//strip comman from last entry
			$sql = rtrim($sql, ",");

			$sql .= " WHERE `id`= :id";
			$pdo_array[':id'] = $data['id'];

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);
		}

		return;
	}


	public function getTags($id) {
		$query = $this->db->prepare("SELECT tag_id FROM `lesson_to_tags` WHERE `lesson_id`= :id");
		$query->execute(array(':id' => $id));
		$tags = $query->fetchAll(PDO::FETCH_OBJ);
		return $tags;
	}

	public function getMyTags($id) {
		$query = $this->db->prepare("SELECT tag_id AS id FROM `lesson_to_tags` WHERE `lesson_id`= :id");
		$query->execute(array(':id' => $id));
		$tags = $query->fetchAll(PDO::FETCH_OBJ);
		$return = array();
		foreach($tags as $tag) {
			$return[] = $tag->id;
		}
		return $return;
	}


	public function getAllTags() {
		$query = $this->db->prepare("SELECT * FROM `lesson_tags`");
		$query->execute();
		$tags = $query->fetchAll(PDO::FETCH_OBJ);
		return $tags;
	}

	public function setTags($id, $tag_array) {
		$sql = "DELETE FROM lesson_to_tags WHERE lesson_id = :id";
		$result = $this->db->prepare($sql);
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array);

		$logger = new Logger();
		$log_sql = "";
		$log_count = 0;
		$batch_count = 0;

		if(count( $tag_array) > 0) {
			foreach ( $tag_array as $tag ) {
				if ( $log_count > 50 ) {
					$batch_count ++;
					$logger->log( "" . $this->getGlobalUser(), "lesson_to_tags", "set tags - batch " . $batch_count, $id, $log_sql );
					$log_sql   = "";
					$log_count = 0;
				}

				$sql                  = "INSERT INTO lesson_to_tags (lesson_id, tag_id) VALUES (:id, :tag_id)";
				$pdo_array[':tag_id'] = $tag;
				$result               = $this->db->prepare( $sql );
				$result->execute( $pdo_array );

				$log_sql .= $logger->fillSQL( $sql, $pdo_array ) . "\n";
				$log_count ++;
			}
		}

		$logger->log("".$this->getGlobalUser(), "game_to_tags", "set tags", $id, $log_sql);
	}

	public function get($data = array()) {
		$sql = "SELECT * FROM lessons";
		$sql .= " WHERE id != ''";

		$pdo_variables = array();

		if (!empty($data['filter_id'])) {
			$sql .= " AND id = ?";
			$pdo_variables[] = $data['filter_id'];
		}
		if (!empty($data['filter_tag'])) {
			$sql .= " AND tag LIKE ?";
			$pdo_variables[] = '%'.$data['filter_tag'].'%';
		}

		if(!empty($data['search'])) {
			$sql .= " AND (title LIKE :search OR content LIKE :search)";
			$pdo_variables[':search'] = '%'.$data['search'].'%';
		}

		$sort_data = array(
			'id',
			'tag',
			'title',
			'sort_order'
		);

		if (isset($data['sort']) && in_array($data['sort'], $sort_data)) {
			$sql .= " ORDER BY sort_order, id";
		}

		if (isset($data['button']) && ($data['button'] == 'DESC')) {
			$sql .= " DESC, LCASE(id) DESC";
		} else {
			$sql .= " ASC, LCASE(id) ASC";
		}

		if (isset($data['start']) || isset($data['limit'])) {
			if (empty($data['start'])) {
				$data['start'] = 0;
			}

			if (empty($data['limit'])) {
				$data['limit'] = 20;
			}

			$sql .= " LIMIT ".$data['start']." , ".$data['limit']." ";

		} else {
			$sql .= " LIMIT 1000";
		}

		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);

		$data = $query->fetchAll(PDO::FETCH_OBJ);
		return $data;
	}

	public function delete($id) {
		$sql = "DELETE FROM `lessons` WHERE `id`=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));

		$sql = "DELETE FROM `lesson_to_tags` WHERE `lesson_id`=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));

		return true;
	}

	public function getLastId() {
		//fetch db from Application for reference
		$article = $this->db->query('SHOW TABLE STATUS WHERE `name` = "lessons"')->fetch();
		return $article['Auto_increment']-1;
	}

	public function getTotalCount() {
		$sql = "SELECT count(*) FROM `lessons`";
		$result = $this->db->prepare($sql);
		$result->execute();
		$number_of_rows = $result->fetchColumn();
		return $number_of_rows;
	}

	function convertFacebookReelLink($videoLink) {
		// Check if the link contains '/reel/'
		if (strpos($videoLink, '/reel/') !== false) {
			// Extract the ID after 'reel/'
			$parts = explode('/reel/', $videoLink);
			if (isset($parts[1])) {
				$id = $parts[1];
				// Construct the new video.php URL
				$newLink = 'https://www.facebook.com/plugins/video.php?height=360&href=https%3A%2F%2Fwww.facebook.com%2Fbjorn.rehnstrom%2Fvideos%2F' . $id;
				return $newLink;
			}
		}
		// Return the original link if it doesn't match the pattern
		return $videoLink;
	}
}
