<?php
class LessonTag extends Application
{
	public $db;
	private $userid;

	public function __construct($userid, $tag_id = '')	{
		//fetch db from Application for reference
		$this->db = parent::getDatabase();
		$this->userid = $userid;
		if($tag_id != '') {
			$sql = "SELECT * FROM `lesson_tags` WHERE `id` = :tag_id";
			$query = $this->db->prepare($sql);
			$query->execute(array(':tag_id' => $tag_id));
			$order = $query->fetch();
			if($order) {
				foreach($order as $n=>$v) {
					$this->$n = $v;
				}
			}
		}
	}

	public function add($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `lesson_tags`(";
			$fields = array();

			//list of fields in the table
			$clearing_fields = array(
				'tag',
				'active',
			);

			foreach($clearing_fields as $field) {
				$fields[$field] = $data[$field];
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}

			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";
				}
				$i++;
			}

			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);
		}
		return;
	}

	public function update($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `lesson_tags` SET";
			$fields = array();

			//list of fields in the table
			$table_fields = array(
				'tag',
				'active',
			);

			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					$fields[$field] = $data[$field];
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//strip comman from last entry
			$sql = rtrim($sql, ",");

			$sql .= " WHERE `id`= :id";
			$pdo_array[':id'] = $data['id'];

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);
		}

		return;
	}

	public function get($data = array()) {
		$sql = "SELECT t.*, tj.lesson_count FROM lesson_tags t LEFT JOIN (SELECT COUNT(id) as lesson_count, tag_id FROM lesson_to_tags GROUP BY tag_id) tj ON tj.tag_id = t.id ";
		$sql .= " WHERE id != ''";

		$pdo_variables = array();

		if (!empty($data['filter_id'])) {
			$sql .= " AND id = ?";
			$pdo_variables[] = $data['filter_id'];
		}
		if (!empty($data['filter_tag'])) {
			$sql .= " AND tag LIKE ?";
			$pdo_variables[] = '%'.$data['filter_tag'].'%';
		}

		$sort_data = array(
			'id',
			'tag',
		);

		if (isset($data['sort']) && in_array($data['sort'], $sort_data)) {
			if ($data['sort'] == 'tag') {
				$sql .= " ORDER BY LCASE(".$data['sort'].")";
				$pdo_variables[] = $data['sort'];

			} else {
				$sql .= " ORDER BY ".$data['sort'];
				$pdo_variables[] = $data['sort'];
			}
		} else {
			$sql .= " ORDER BY id";
		}

		if (isset($data['button']) && ($data['button'] == 'DESC')) {
			$sql .= " DESC, LCASE(id) DESC";
		} else {
			$sql .= " ASC, LCASE(id) ASC";
		}

		if (isset($data['start']) || isset($data['limit'])) {
			if (empty($data['start'])) {
				$data['start'] = 0;
			}

			if (empty($data['limit'])) {
				$data['limit'] = 20;
			}

			$sql .= " LIMIT ".$data['start']." , ".$data['limit']." ";

		}

		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);

		$data = $query->fetchAll(PDO::FETCH_OBJ);
		return $data;
	}

	public function delete($id) {
		$sql = "DELETE FROM `lesson_tags` WHERE `id`=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));

		$sql = "DELETE FROM `resource_to_tags` WHERE `tag_id`=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));

		return true;
	}

	public function getLastId() {
		//fetch db from Application for reference
		$article = $this->db->query('SHOW TABLE STATUS WHERE `name` = "lesson_tags"')->fetch();
		return $article['Auto_increment']-1;
	}

	public function getTotalCount() {
		$sql = "SELECT count(*) FROM `lesson_tags`";
		$result = $this->db->prepare($sql);
		$result->execute();
		$number_of_rows = $result->fetchColumn();
		return $number_of_rows;
	}

	public function isTagSeoUrlAvailable($url) {
		$sql = "SELECT count(*) FROM `lesson_tags` WHERE seo_url = :url";
		$query = $this->db->prepare($sql);
		$query->execute(array('url'=>$url));
		$number_of_rows = $query->fetchColumn();
		if($number_of_rows > 0) {
			return false;
		}
		return true;
	}

	public function getButtonsByTagId($id) {
		$query = $this->db->prepare("SELECT button_id as id FROM `lesson_to_tags` WHERE tag_id = :tag_id");
		$query->execute(array(':tag_id' => $id));
		$results = $query->fetchAll(PDO::FETCH_OBJ);
		$return_array = array();
		foreach($results as $id) {
			$return_array[] = $id->id;
		}
		return $return_array;
	}

	public function createLessonTagTables($user_id = "") {
		$user = "";
		if(!empty($user_id)) {
			$user = $user_id;
		} else {
			if(!empty($this->userid)) {
				$user = $this->userid;
			}
		}
		if(empty($user)) {
			return false;
		}

		$query = $this->db->prepare("CREATE TABLE IF NOT EXISTS `lesson_tags` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `tag` varchar(255) NOT NULL,
		  `active` int(11) DEFAULT '1',
		  PRIMARY KEY (`id`)
		) ENGINE=InnoDB DEFAULT CHARSET=utf8");
		$results = $query->execute();

		$query = $this->db->prepare("CREATE TABLE IF NOT EXISTS `lesson_to_tags` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `resource_id` int(11) NOT NULL,
		  `tag_id` int(12) NOT NULL,
		  PRIMARY KEY (`id`),
		  KEY `resource_id` (`resource_id`)
		) ENGINE=InnoDB DEFAULT CHARSET=utf8");

		return true;
	}

}
