<?php
class User extends Application
{
	
	public $db;
	public $files_directory;
	public $skeleton_table_id;
	
	public function __construct($id='')
	{
		//set the files directory
		$this->files_directory = parent::getFilesDirectory();

		//fetch db from Application for reference
		$this->db = parent::getDatabase();
		
		//fetch skeleton_table_id from Application for reference
		$this->skeleton_table_id = parent::getSkeletonTableId();
		
		
		$query = $this->db->prepare("SELECT * FROM `user` WHERE `user_email`= :id OR `user_id`= :id OR `user_alias`= :id");
		$query->execute(array(':id' => $id));
		$user = $query->fetch();
		if($user) {
			foreach($user as $n=>$v) {
				$this->$n = $v;
			}
		}
	}
	
	public function addUser($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `user`(";
			$fields = array();
			
			//list of fields in the table
			$clearing_fields = array(
				'user_level',
				'user_first',
				'user_last',
				'user_email',
				'user_alias',
				'user_password',
				'user_note',
				'user_password',
				'user_lang',
				'user_locked'
			);
			
			foreach($clearing_fields as $field) {
				if($field != 'user_password') {
					if(!empty($data[$field])) {
						$fields[$field] = $data[$field];
					}
				} else {
					$fields[$field] = md5($data[$field]);
				}
			}
			
			$fields["created"] = date("Y-m-d H:i:s");
			$fields["updated"] = date("Y-m-d H:i:s");
			
			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}
	    	
			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";	
				}
				$i++;
			}
			
			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";	
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}
			
			//prepare the query
			$query = $this->db->prepare($sql);
			
			//execute query with all variables
			$query->execute($pdo_array);
			
			$user_id = $this->db->lastInsertId();
			
			$logger = new Logger();
			$logger->logPDO($this->user_id, "user", "add", $user_id, $sql, $pdo_array);
			
			//echo "<p>".$logger->fillSQL($sql, $pdo_array)."</p>";
		}
		return $user_id;
	}

	public function updateUser($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `user` SET";
			$fields = array();
			
			//list of fields in the table
			$table_fields = array(
				'user_id',
				'user_level',
				'user_first',
				'user_last',
				'user_email',
				'user_alias',
				'user_password',
				'user_note',
				'user_password',
				'user_lang',
				'user_locked'
			);
			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					if($field != 'user_password') {
						$fields[$field] = $data[$field];
					} else {
						$fields[$field] = md5($data[$field]);
					}
				}
			}
			
			$fields['updated'] = date("Y-m-d H:i:s");
			
			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}
			
			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}
			
			//strip comman from last entry
			$sql = rtrim($sql, ",");
			
			$sql .= " WHERE `user_id`= :user_id"; 
			
			//prepare the query
			$query = $this->db->prepare($sql);
			
			//execute query with all variables
			$query->execute($pdo_array);
			
			$logger = new Logger();
			$logger->logPDO($this->user_id, "user", "update", $pdo_array[':user_id'], $sql, $pdo_array);
		}
		return;
	}

	public function resetPasswordRequest($data = array(), $lang) {
    	if(!empty($data)) {
    		//create the password reset request in the table
    		$query = $this->db->prepare("INSERT INTO password_reset_requests (`entered`, `expired`, `client_email`, `verification_code`, `request_ip_address`) VALUES (:entered, :expired, :email, :vcode, :ip)");
    		$query->execute($data);
			$request_id = $this->db->lastInsertId();
			
			//send email with a link contain the code and id that links to the reset password page
			include_once(__DIR__.'/class.mailer.php');
			$mailer = new Mailer();
			$to = $data[':email'];
			if ($lang == 'eng') {
				$from = "noreply@willum.arcent.io";
				$subject = "Willumog: Your Requested Password Reset";
				$message = 	"	
							<h2>To Reset your willumog password...</h2>
							<p>...simply follow <a href='https://".$_SERVER['SERVER_NAME']."/reset_password.php?id=".$request_id."&validation=".$data[':vcode']."'>this link</a></p>
							<br>
							<p>If you did not request this password reset, you don't have to do anything. But if it becomes a reoccuring issue, please contact us so we can investigate. Thanks!</p>
							";
			} else {
				$from = "noreply@willum.arcent.io";
				$subject = "Willumog: Någon har bett om att återställa ditt lösenord";
				$message = 	"	
							<h2>För att byta ditt lösenord hos Willumog...</h2>
							<p>...använd <a href='https://".$_SERVER['SERVER_NAME']."/reset_password.php?id=".$request_id."&validation=".$data[':vcode']."'>denna länk</a></p>
							<br>
							<p>Om du inte bad om att återställa ditt lösenord behöver du inte göra någonting. Men om du får detta mail flertal gånger kontakta oss gärna så att vi kan undersöka situationen. Tack!</p>
							";
			}
			$mailer->sendHTMLMail($to, $from, $subject, $message);
		}
		return $request_id;
	}
	
	public function getFullName() {
		return $this->user_first . " " . $this->user_last;
	}
	
	public function delete($id) {
		$sql = "UPDATE `user` SET user_active = 0 WHERE user_id = :id"; 
		$result = $this->db->prepare($sql); 
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array); 
		
		$logger = new Logger();
		$logger->logPDO($this->user_id, "user", "delete", $id, $sql, $pdo_array);
		
		return true;
	}
	
	public function getUsers() {
		//fetch db from Application for reference
		$user = $this->db->query("SELECT * FROM `user`")->fetchAll(PDO::FETCH_ASSOC);
		return $user;
	}
	
	public function getUser($user_id) {
		$sql = "SELECT * FROM `user` WHERE `user_id`= :user_id";
		$query = $this->db->prepare($sql);
		$query->execute(array(':user_id' => $user_id));
		$r_user = $query->fetch(PDO::FETCH_OBJ);
		return $r_user;
	}
	
	public function getUserNameById($id) {
		$sql = "SELECT * FROM `user` WHERE `user_id`=:user_id";
		$query = $this->db->prepare($sql);
		$query->execute(array('user_id'=>$id));
		$user = $query->fetch();
		return $user['user_first'] . " " . $user['user_last'];
	}
	
	public function updateLastOnlineTime() {
		$sql = "UPDATE `user` SET user_last_online = :time WHERE `user_id`= :id";
		$pdo_array[':id'] = $this->user_id;
		$pdo_array[':time'] = date("Y-m-d H:i:s");
		$query = $this->db->prepare($sql);
		$query->execute($pdo_array);
		return true;
	}
	
	public function updateLastActionTime() {
		$sql = "UPDATE `user` SET user_last_active = :time WHERE `user_id`= :id";
		$pdo_array[':id'] = $this->user_id;
		$pdo_array[':time'] = date("Y-m-d H:i:s");
		$query = $this->db->prepare($sql);
		$query->execute($pdo_array);
		return true;
	}
	
	public function getUserSearchSelectOptions($searchterm, $exclude = "") {
		$sql = "SELECT user_id, user_first, user_last, user_company FROM `user` WHERE";
		$sql .= " (`user_id` = :searchterm";
		$sql .= " OR `user_first` LIKE :searchtermflex";
		$sql .= " OR `user_last` LIKE :searchtermflex";
		$sql .= " OR `user_company` LIKE :searchtermflex)";
		$sql .= " AND `user_active` = 1";
		if ($exclude != "") {
			$exclude_array = explode(",",$exclude);
			foreach ($exclude_array as $index=>$ex_id) {
				$sql .= " AND `user_id` != :ex".$index;
				$pdo_array[':ex'.$index] = $ex_id;
			}
		}
		$sql .= " ORDER BY user_id ASC LIMIT 50";
		
		$pdo_array[':searchterm'] = $searchterm;
		$pdo_array[':searchtermflex'] = "%".$searchterm."%";
		$query = $this->db->prepare($sql);
		$query->execute($pdo_array);
		
		$data = $query->fetchAll(PDO::FETCH_OBJ);
		return $data;
	}
	
	public function getFilteredUsers($data = array()) {
		$sql = "SELECT * FROM `user` "; 
		$sql .= " WHERE user_id != ''";
		$filter_inactive = true;
		
		$pdo_variables = array();
		
		if (!empty($data['filter_id'])) {
			if (!empty(str_replace(" ","",$data['filter_id']))) {
				$filter_inactive = false;
				$explode = explode (" ", $data['filter_id']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "user_id = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}
		
		if (!empty($data['exclude_id'])) {
			if (!empty(str_replace(" ","",$data['exclude_id']))) {
				$explode = explode (" ", $data['exclude_id']);
				foreach ($explode as $val) {
					if (!empty($val)) {
						$sql .= " AND NOT user_id = ?";
						$pdo_variables[] = $val;
					}
				}
			}
		}
		
		if (!empty($data['filter_name'])) {
			if (!empty(str_replace(" ","",$data['filter_name']))) {
				$filter_inactive = false;
				$explode = explode (" ", $data['filter_name']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " AND ";
					}
					$sql .= "(user_first LIKE ? OR user_last LIKE ?)";
					$pdo_variables[] = "%".$val."%";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}
		
		if (!empty($data['filter_note'])) {
			if (!empty(str_replace(" ","",$data['filter_note']))) {
				$filter_inactive = false;
				$explode = explode (" ", $data['filter_note']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " AND ";
					}
					$sql .= "user_note LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}
		
		if (!empty($data['filter_user_level'])) {
			if (!empty(str_replace(" ","",$data['filter_user_level']))) {
				$filter_inactive = false;
				$explode = explode (" ", $data['filter_user_level']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " AND ";
					}
					$sql .= "user_level = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}
		
		if ($filter_inactive) {
			$sql .= " AND user_active = 1";
		}
		
		if (!empty($data['sort'])) {
			$sql .= " ORDER BY ?";
			$pdo_variables[] = $data['sort'];
		} else {
			$sql .= " ORDER BY user_id";	
		}
			
		if (isset($data['order']) && ($data['order'] == 'ASC')) {
			$sql .= " ASC, user_id ASC";
		} else {
			$sql .= " DESC, user_id DESC";
		}
			
		if (isset($data['start']) || isset($data['limit'])) {
			if (empty($data['start'])) {
				$data['start'] = 0;
			}				
			if (empty($data['limit'])) {
				$data['limit'] = 20;
			}	
			$sql .= " LIMIT ".$data['start']." , ".$data['limit']." ";
		}
		
		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);
		
		//$logger = new Logger();
		//echo "<p>".$logger->fillSQLsequential($sql, $pdo_variables)."</p>";

		$data = $query->fetchAll(PDO::FETCH_OBJ);
		return $data;
	}

	public function checkRecentPasswordReset() {
		$sql = "SELECT COUNT(id) as itemcount FROM password_reset_requests WHERE client_email = :email AND entered > :start";
		$pdo_array[':email'] = $this->user_email;
		$pdo_array[':start'] = date("Y-m-d H:i:s", strtotime("-1 day"));
		
		$query = $this->db->prepare($sql);
		$query->execute($pdo_array);
		
		$data = $query->fetch(PDO::FETCH_OBJ);
		
		if ($data->itemcount >= 300) {
			return true;
		} else {
			return false;
		}
	}
}